==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/en_GB.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "You created the team {circle}",
    "{author} created the team {circle}" : "{author} created the team {circle}",
    "You deleted {circle}" : "You deleted {circle}",
    "{author} deleted {circle}" : "{author} deleted {circle}",
    "You made {member} join {circle}" : "You made {member} join {circle}",
    "{author} made {member} join {circle}" : "{author} made {member} join {circle}",
    "You added team {member} as member to {circle}" : "You added team {member} as member to {circle}",
    "{author} added team {member} as member to {circle}" : "{author} added team {member} as member to {circle}",
    "You made {member} leave {circle}" : "You made {member} leave {circle}",
    "{author} made {member} leave {circle}" : "{author} made {member} leave {circle}",
    "You removed {member} from {circle}" : "You removed {member} from {circle}",
    "{author} removed {member} from {circle}" : "{author} removed {member} from {circle}",
    "You joined {circle}" : "You joined {circle}",
    "{member} joined {circle}" : "{member} joined {circle}",
    "You accepted the invitation to join {circle}" : "You accepted the invitation to join {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} accepted the invitation to join {circle}",
    "You added {member} as member to {circle}" : "You added {member} as member to {circle}",
    "You have been added as member to {circle} by {author}" : "You have been added as member to {circle} by {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} has been added as member to {circle} by {author}",
    "You added {external} to {circle}" : "You added {external} to {circle}",
    "{external} has been added to {circle} by {author}" : "{external} has been added to {circle} by {author}",
    "You accepted {member}'s request to join {circle}" : "You accepted {member}'s request to join {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Your request to join {circle} has been accepted by {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}'s request to join {circle} has been accepted by {author}",
    "You left {circle}" : "You left {circle}",
    "{member} left {circle}" : "{member} left {circle}",
    "You declined the invitation to join {circle}" : "You declined the invitation to join {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declined an invitation to join {circle}",
    "You cancelled your request to join {circle}" : "You cancelled your request to join {circle}",
    "{member} cancelled a request to join {circle}" : "{member} cancelled a request to join {circle}",
    "You have been removed from {circle} by {author}" : "You have been removed from {circle} by {author}",
    "{member} has been removed from {circle} by {author}" : "{member} has been removed from {circle} by {author}",
    "You removed {external} from {circle}" : "You removed {external} from {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} has been removed from {circle} by {author}",
    "You cancelled {member}'s invitation to join {circle}" : "You cancelled {member}'s invitation to join {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Your invitation to join {circle} has been cancelled by {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelled {member}'s invitation to join {circle}",
    "You dismissed {member}'s request to join {circle}" : "You dismissed {member}'s request to join {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Your request to join {circle} has been dismissed by {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}'s request to join {circle} has been dismissed by {author}",
    "You invited {member} to join {circle}" : "You invited {member} to join {circle}",
    "You have been invited to join {circle} by {author}" : "You have been invited to join {circle} by {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} has been invited to join {circle} by {author}",
    "You changed {member}'s level in {circle} to %1$s" : "You changed {member}'s level in {circle} to %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} changed your level in {circle} to %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} changed {member}'s level in {circle} to %1$s",
    "You sent a request to join {circle}" : "You sent a request to join {circle}",
    "{member} sent a request to join {circle}" : "{member} sent a request to join {circle}",
    "You are the new owner of {circle}" : "You are the new owner of {circle}",
    "{member} is the new owner of {circle}" : "{member} is the new owner of {circle}",
    "Teams" : "Teams",
    "On events happening in a <strong>team</strong> of which you are a member" : "On events happening in a <strong>team</strong> of which you are a member",
    "Any important event in a <strong>team</strong> you are moderating" : "Any important event in a <strong>team</strong> you are moderating",
    "On global events happening in any <strong>team</strong>" : "On global events happening in any <strong>team</strong>",
    "Single" : "Single",
    "Personal" : "Personal",
    "System" : "System",
    "Visible" : "Visible",
    "Open" : "Open",
    "Invite" : "Invite",
    "Join request" : "Join request",
    "Friends" : "Friends",
    "Password protected" : "Password protected",
    "No Owner" : "No Owner",
    "Hidden" : "Hidden",
    "Backend" : "Backend",
    "Local" : "Local",
    "Root" : "Root",
    "Team invite" : "Team invite",
    "Federated" : "Federated",
    "Mount point" : "Mount point",
    "Nextcloud Account" : "Nextcloud Account",
    "Nextcloud Group" : "Nextcloud Group",
    "Email address" : "Email address",
    "Contact" : "Contact",
    "Team" : "Team",
    "Nextcloud App" : "Nextcloud App",
    "Teams App" : "Teams App",
    "Admin Command Line" : "Admin Command Line",
    "Member" : "Member",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "%s shared »%s« with you." : "%s shared »%s« with you.",
    "%s shared »%s« with \"%s\"." : "%s shared »%s« with \"%s\".",
    "%s on %s" : "%s on %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it.",
    "Password to access »%1$s« shared to you by %2$s" : "Password to access »%1$s« shared to you by %2$s",
    "Password to access »%s«" : "Password to access »%s«",
    "It is protected with the following password:" : "It is protected with the following password:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Click the button below to open it.",
    "Open »%s«" : "Open »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s shared multiple files with you. You should have already received a separate email with a link to access them.",
    "Password to access files shared to you by %1$s" : "Password to access files shared to you by %1$s",
    "Password to access files" : "Password to access files",
    "%s shared multiple files with \"%s\"." : "%s shared multiple files with \"%s\".",
    "%s shared multiple files with you." : "%s shared multiple files with you.",
    "Boot up" : "Boot up",
    "Nextcloud Initialization" : "Nextcloud Initialisation",
    "Circles App Initialization" : "Circles App Initialisation",
    "Fresh installation status" : "Fresh installation status",
    "Building Local Database" : "Building Local Database",
    "Testing Basic Team Creation" : "Testing Basic Team Creation",
    "Adding local users and moderators" : "Adding local users and moderators",
    "Show all teams" : "Show all teams",
    "Create a new team" : "Create a new team",
    "Files" : "Files",
    "This feature is not available for personal teams" : "This feature is not available for personal teams",
    "The team is not federated" : "The team is not federated",
    "You cannot join this team" : "You cannot join this team",
    "This member is not a moderator" : "This member is not a moderator",
    "Insufficient privileges" : "Insufficient privileges",
    "This member does not exist" : "This member does not exist",
    "This member is the owner of the team" : "This member is the owner of the team",
    "Level cannot be changed for this type of member" : "Level cannot be changed for this type of member",
    "You are already a member of this team" : "You are already a member of this team",
    "You have been blocked from this team" : "You have been blocked from this team",
    "The account is already a member of this team" : "The account is already a member of this team",
    "The account has already been invited into this team" : "The account has already been invited into this team",
    "%s (Team owned by %s)" : "%s (Team owned by %s)",
    "You are now a member of the Team \"%2$s\"" : "You are now a member of the Team \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "You have been invited by %1$s into the Team \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s sent a request to be a member of the Team \"%2$s\"",
    "Accept" : "Accept",
    "Refuse" : "Refuse",
    "Leave the team" : "Leave the team",
    "%s" : "%s",
    "Personal team" : "Personal team",
    "%s owned by %s" : "%s owned by %s",
    "You have no permission to create a new team" : "You have no permission to create a new team",
    "%s shared a file with \"%s\"." : "%s shared a file with \"%s\".",
    "%s shared a file with you." : "%s shared a file with you.",
    "%1$s shared %2$s with %3$s" : "%1$s shared %2$s with %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s shared %2$s with \"%3$s\"",
    "Open %s" : "Open %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s shared some content with you. You should have already received a separate email with a link to access it.",
    "Password to access content shared with you by %1$s" : "Password to access content shared with you by %1$s",
    "Password to access content" : "Password to access content",
    "This item is already shared with this team" : "This item is already shared with this team",
    "Bring cloud-users closer together." : "Bring cloud-users closer together.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose.",
    "Failed to load teams" : "Failed to load teams",
    "Try again" : "Try again",
    "No teams found" : "No teams found",
    "Join or create teams to see them here." : "Join or create teams to see them here.",
    "Create your first team" : "Create your first team",
    "Loading…" : "Loading…",
    "More teams" : "More teams",
    "No files in here" : "No files in here",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "Shared to Circles" : "Shared to Circles"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/en_GB.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "You created the team {circle}",
    "{author} created the team {circle}" : "{author} created the team {circle}",
    "You deleted {circle}" : "You deleted {circle}",
    "{author} deleted {circle}" : "{author} deleted {circle}",
    "You made {member} join {circle}" : "You made {member} join {circle}",
    "{author} made {member} join {circle}" : "{author} made {member} join {circle}",
    "You added team {member} as member to {circle}" : "You added team {member} as member to {circle}",
    "{author} added team {member} as member to {circle}" : "{author} added team {member} as member to {circle}",
    "You made {member} leave {circle}" : "You made {member} leave {circle}",
    "{author} made {member} leave {circle}" : "{author} made {member} leave {circle}",
    "You removed {member} from {circle}" : "You removed {member} from {circle}",
    "{author} removed {member} from {circle}" : "{author} removed {member} from {circle}",
    "You joined {circle}" : "You joined {circle}",
    "{member} joined {circle}" : "{member} joined {circle}",
    "You accepted the invitation to join {circle}" : "You accepted the invitation to join {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} accepted the invitation to join {circle}",
    "You added {member} as member to {circle}" : "You added {member} as member to {circle}",
    "You have been added as member to {circle} by {author}" : "You have been added as member to {circle} by {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} has been added as member to {circle} by {author}",
    "You added {external} to {circle}" : "You added {external} to {circle}",
    "{external} has been added to {circle} by {author}" : "{external} has been added to {circle} by {author}",
    "You accepted {member}'s request to join {circle}" : "You accepted {member}'s request to join {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Your request to join {circle} has been accepted by {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}'s request to join {circle} has been accepted by {author}",
    "You left {circle}" : "You left {circle}",
    "{member} left {circle}" : "{member} left {circle}",
    "You declined the invitation to join {circle}" : "You declined the invitation to join {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declined an invitation to join {circle}",
    "You cancelled your request to join {circle}" : "You cancelled your request to join {circle}",
    "{member} cancelled a request to join {circle}" : "{member} cancelled a request to join {circle}",
    "You have been removed from {circle} by {author}" : "You have been removed from {circle} by {author}",
    "{member} has been removed from {circle} by {author}" : "{member} has been removed from {circle} by {author}",
    "You removed {external} from {circle}" : "You removed {external} from {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} has been removed from {circle} by {author}",
    "You cancelled {member}'s invitation to join {circle}" : "You cancelled {member}'s invitation to join {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Your invitation to join {circle} has been cancelled by {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelled {member}'s invitation to join {circle}",
    "You dismissed {member}'s request to join {circle}" : "You dismissed {member}'s request to join {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Your request to join {circle} has been dismissed by {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}'s request to join {circle} has been dismissed by {author}",
    "You invited {member} to join {circle}" : "You invited {member} to join {circle}",
    "You have been invited to join {circle} by {author}" : "You have been invited to join {circle} by {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} has been invited to join {circle} by {author}",
    "You changed {member}'s level in {circle} to %1$s" : "You changed {member}'s level in {circle} to %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} changed your level in {circle} to %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} changed {member}'s level in {circle} to %1$s",
    "You sent a request to join {circle}" : "You sent a request to join {circle}",
    "{member} sent a request to join {circle}" : "{member} sent a request to join {circle}",
    "You are the new owner of {circle}" : "You are the new owner of {circle}",
    "{member} is the new owner of {circle}" : "{member} is the new owner of {circle}",
    "Teams" : "Teams",
    "On events happening in a <strong>team</strong> of which you are a member" : "On events happening in a <strong>team</strong> of which you are a member",
    "Any important event in a <strong>team</strong> you are moderating" : "Any important event in a <strong>team</strong> you are moderating",
    "On global events happening in any <strong>team</strong>" : "On global events happening in any <strong>team</strong>",
    "Single" : "Single",
    "Personal" : "Personal",
    "System" : "System",
    "Visible" : "Visible",
    "Open" : "Open",
    "Invite" : "Invite",
    "Join request" : "Join request",
    "Friends" : "Friends",
    "Password protected" : "Password protected",
    "No Owner" : "No Owner",
    "Hidden" : "Hidden",
    "Backend" : "Backend",
    "Local" : "Local",
    "Root" : "Root",
    "Team invite" : "Team invite",
    "Federated" : "Federated",
    "Mount point" : "Mount point",
    "Nextcloud Account" : "Nextcloud Account",
    "Nextcloud Group" : "Nextcloud Group",
    "Email address" : "Email address",
    "Contact" : "Contact",
    "Team" : "Team",
    "Nextcloud App" : "Nextcloud App",
    "Teams App" : "Teams App",
    "Admin Command Line" : "Admin Command Line",
    "Member" : "Member",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "%s shared »%s« with you." : "%s shared »%s« with you.",
    "%s shared »%s« with \"%s\"." : "%s shared »%s« with \"%s\".",
    "%s on %s" : "%s on %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it.",
    "Password to access »%1$s« shared to you by %2$s" : "Password to access »%1$s« shared to you by %2$s",
    "Password to access »%s«" : "Password to access »%s«",
    "It is protected with the following password:" : "It is protected with the following password:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Click the button below to open it.",
    "Open »%s«" : "Open »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s shared multiple files with you. You should have already received a separate email with a link to access them.",
    "Password to access files shared to you by %1$s" : "Password to access files shared to you by %1$s",
    "Password to access files" : "Password to access files",
    "%s shared multiple files with \"%s\"." : "%s shared multiple files with \"%s\".",
    "%s shared multiple files with you." : "%s shared multiple files with you.",
    "Boot up" : "Boot up",
    "Nextcloud Initialization" : "Nextcloud Initialisation",
    "Circles App Initialization" : "Circles App Initialisation",
    "Fresh installation status" : "Fresh installation status",
    "Building Local Database" : "Building Local Database",
    "Testing Basic Team Creation" : "Testing Basic Team Creation",
    "Adding local users and moderators" : "Adding local users and moderators",
    "Show all teams" : "Show all teams",
    "Create a new team" : "Create a new team",
    "Files" : "Files",
    "This feature is not available for personal teams" : "This feature is not available for personal teams",
    "The team is not federated" : "The team is not federated",
    "You cannot join this team" : "You cannot join this team",
    "This member is not a moderator" : "This member is not a moderator",
    "Insufficient privileges" : "Insufficient privileges",
    "This member does not exist" : "This member does not exist",
    "This member is the owner of the team" : "This member is the owner of the team",
    "Level cannot be changed for this type of member" : "Level cannot be changed for this type of member",
    "You are already a member of this team" : "You are already a member of this team",
    "You have been blocked from this team" : "You have been blocked from this team",
    "The account is already a member of this team" : "The account is already a member of this team",
    "The account has already been invited into this team" : "The account has already been invited into this team",
    "%s (Team owned by %s)" : "%s (Team owned by %s)",
    "You are now a member of the Team \"%2$s\"" : "You are now a member of the Team \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "You have been invited by %1$s into the Team \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s sent a request to be a member of the Team \"%2$s\"",
    "Accept" : "Accept",
    "Refuse" : "Refuse",
    "Leave the team" : "Leave the team",
    "%s" : "%s",
    "Personal team" : "Personal team",
    "%s owned by %s" : "%s owned by %s",
    "You have no permission to create a new team" : "You have no permission to create a new team",
    "%s shared a file with \"%s\"." : "%s shared a file with \"%s\".",
    "%s shared a file with you." : "%s shared a file with you.",
    "%1$s shared %2$s with %3$s" : "%1$s shared %2$s with %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s shared %2$s with \"%3$s\"",
    "Open %s" : "Open %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s shared some content with you. You should have already received a separate email with a link to access it.",
    "Password to access content shared with you by %1$s" : "Password to access content shared with you by %1$s",
    "Password to access content" : "Password to access content",
    "Federated Teams" : "Federated Teams",
    "This item is already shared with this team" : "This item is already shared with this team",
    "Bring cloud-users closer together." : "Bring cloud-users closer together.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose.",
    "Unable to update federated teams config" : "Unable to update federated teams config",
    "Invalid URL format. Please provide a valid URL." : "Invalid URL format. Please provide a valid URL.",
    "Changed frontal cloud URL" : "Changed frontal cloud URL",
    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Federation allows you to share teams with other trusted servers and make them discoverable across instances.",
    "Enable federated teams" : "Enable federated teams",
    "Frontal URL" : "Frontal URL",
    "https://…" : "https://…",
    "The public URL used by other instances to discover and connect to your teams." : "The public URL used by other instances to discover and connect to your teams.",
    "Failed to load teams" : "Failed to load teams",
    "Try again" : "Try again",
    "No teams found" : "No teams found",
    "Join or create teams to see them here." : "Join or create teams to see them here.",
    "Create your first team" : "Create your first team",
    "Loading…" : "Loading…",
    "More teams" : "More teams",
    "No files in here" : "No files in here",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "Shared to Circles" : "Shared to Circles"
},
"nplurals=2; plural=(n != 1);");
